Struct plaid::transactions::AccountBalances[][src]

pub struct AccountBalances {
    pub available: Option<f64>,
    pub current: f64,
    pub limit: Option<f64>,
    pub iso_currency_code: Option<String>,
    pub unofficial_currency_code: Option<String>,
}

Fields

available: Option<f64>

The amount of funds available to be withdrawn from the account, as determined by the financial institution.

current: f64

The total amount of funds in or owed by the account.

limit: Option<f64>

For credit-type accounts, this represents the credit limit. For depository-type accounts, this represents the pre-arranged overdraft limit, which is common for current (checking) accounts in Europe. In North America, this field is typically only available for credit-type accounts.

iso_currency_code: Option<String>

The ISO-4217 currency code of the balance. Always null if unofficial_currency_code is non-null.

unofficial_currency_code: Option<String>

The unofficial currency code associated with the balance. Always null if iso_currency_code is non-null.