Struct plaid::transactions::GetTransactionsResponse[][src]

pub struct GetTransactionsResponse {
    pub request_id: String,
    pub accounts: Vec<Account>,
    pub transactions: Vec<Transaction>,
    pub total_transactions: i32,
    pub item: Item,
}

Fields

request_id: String

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

accounts: Vec<Account>

An array containing the accounts associated with the Item for which transactions are being returned. Each transaction can be mapped to its corresponding account via the account_id field.

transactions: Vec<Transaction>

An array containing transactions from the account. Transactions are returned in reverse chronological order, with the most recent at the beginning of the array. The maximum number of transactions returned is determined by the count parameter.

total_transactions: i32

The total number of transactions available within the date range specified. If total_transactions is larger than the size of the transactions array, more transactions are available and can be fetched via manipulating the offset parameter.

item: Item

Metadata about the Item.