Struct plaid::transactions::PaymentMeta[][src]

pub struct PaymentMeta {
    pub reference_number: Option<String>,
    pub ppd_id: Option<String>,
    pub payee: Option<String>,
    pub by_order_of: Option<String>,
    pub payer: Option<String>,
    pub payment_method: Option<String>,
    pub payment_processor: Option<String>,
    pub reason: Option<String>,
}

Transaction information specific to inter-bank transfers.

Fields

reference_number: Option<String>

The transaction reference number supplied by the financial institution.

ppd_id: Option<String>

The ACH PPD ID for the payer.

payee: Option<String>

For transfers, the party that is receiving the transaction.

by_order_of: Option<String>

The party initiating a wire transfer. Will be null if the transaction is not a wire transfer.

payer: Option<String>

For transfers, the party that is paying the transaction.

payment_method: Option<String>

The type of transfer, e.g. 'ACH'

payment_processor: Option<String>

The name of the payment processor

reason: Option<String>

The payer-supplied description of the transfer.