Struct plaid::transactions::RefreshTransactionsResponse[][src]

pub struct RefreshTransactionsResponse {
    pub request_id: String,
}

Fields

request_id: String

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.