Struct plaid::transactions::Transaction[][src]

pub struct Transaction {
    pub transaction_id: String,
    pub account_owner: Option<String>,
    pub pending_transaction_id: Option<String>,
    pub pending: bool,
    pub payment_channel: String,
    pub payment_meta: PaymentMeta,
    pub name: String,
    pub merchant_name: Option<String>,
    pub location: Location,
    pub authorized_date: Option<NaiveDate>,
    pub authorized_datetime: Option<DateTime<Utc>>,
    pub date: NaiveDate,
    pub datetime: Option<DateTime<Utc>>,
    pub category_id: String,
    pub category: Option<Vec<String>>,
    pub unofficial_currency_code: Option<String>,
    pub iso_currency_code: Option<String>,
    pub amount: f64,
    pub account_id: String,
    pub transaction_code: Option<String>,
}

Fields

transaction_id: String

The unique ID of the transaction. Like all Plaid identifiers, the transaction_id is case sensitive.

account_owner: Option<String>

The name of the account owner. This field is not typically populated and only relevant when dealing with sub-accounts.

pending_transaction_id: Option<String>

The ID of a posted transaction's associated pending transaction, where applicable.

pending: bool

When true, identifies the transaction as pending or unsettled. Pending transaction details (name, type, amount, category ID) may change before they are settled.

payment_channel: String

The channel used to make a payment. Possible values: online, in store, other

payment_meta: PaymentMeta

Transaction information specific to inter-bank transfers. If the transaction was not an inter-bank transfer, all fields will be null.

name: String

The merchant name or transaction description.

merchant_name: Option<String>

The merchant name, as extracted by Plaid from the name field.

location: Location

A representation of where a transaction took place

authorized_date: Option<NaiveDate>

The date that the transaction was authorized. Dates are returned in an ISO 8601 format ( YYYY-MM-DD ).

authorized_datetime: Option<DateTime<Utc>>

Date and time when a transaction was authorized in ISO 8601 format ( YYYY-MM-DDTHH:mm:ssZ ).

date: NaiveDate

For pending transactions, the date that the transaction occurred; for posted transactions, the date that the transaction posted. Both dates are returned in an ISO 8601 format ( YYYY-MM-DD ).

datetime: Option<DateTime<Utc>>

Date and time when a transaction was posted in ISO 8601 format ( YYYY-MM-DDTHH:mm:ssZ ).

category_id: String

The ID of the category to which this transaction belongs.

category: Option<Vec<String>>

A hierarchical array of the categories to which this transaction belongs

unofficial_currency_code: Option<String>

The unofficial currency code associated with the transaction.

iso_currency_code: Option<String>

The ISO-4217 currency code of the transaction.

amount: f64

The settled value of the transaction, denominated in the account's currency, as stated in iso_currency_code or unofficial_currency_code. Positive values when money moves out of the account; negative values when money moves in. For example, debit card purchases are positive; credit card payments, direct deposits, and refunds are negative.

account_id: String

The ID of the account in which this transaction occurred.

transaction_code: Option<String>

An identifier classifying the transaction type. This field is only populated for European institutions. For institutions in the US and Canada, this field is set to null. Possible values: adjustment, atm, bank charge, bill payment, cash, cashback, cheque, direct debit, interest, purchase, standing order, transfer, null